@@ -1,12 +1,14 @@
 """
 Test for basic register reading
 """
+import unittest
 from typing import Tuple, Optional, Iterator, Union, Dict, Type, cast
 from abc import ABC, abstractmethod
 from unittest.mock import patch
 
 # pylint: disable-next=unused-wildcard-import,wildcard-import
 from peakrdl_python.lib import *
+from peakrdl_python.lib.utility_functions import legal_register_width
 
 from .simple_components import ReadOnlyRegisterToTest, WriteOnlyRegisterToTest, \
     ReadWriteRegisterToTest, CallBackTestWrapper
@@ -43,7 +45,7 @@ class RegTestBase(CallBackTestWrapper, ABC):
             """
 
             # pylint: disable=duplicate-code
-            def __init__(self,
+            def __init__(self, *,
                          callbacks: Optional[CallbackSet],
                          address: int,
                          logger_handle: str,
@@ -101,6 +103,7 @@ class RegTestBase(CallBackTestWrapper, ABC):
                                       logger_handle='dut_wrapper', inst_name='dut_wrapper',
                                       reg_type=self.reg_type)
 
+
 class TestReadOnly(RegTestBase):
     """
     Test for read only register
@@ -127,7 +130,6 @@ class TestReadOnly(RegTestBase):
         """
         return cast(ReadOnlyRegisterToTest, self.dut_wrapper.dut)
 
-
     def test_register_read(self) -> None:
         """
         Test register read
@@ -180,6 +182,7 @@ class TestReadOnly(RegTestBase):
 
             write_patch.assert_not_called()
 
+
 class TestWrite(RegTestBase):
     """
     Test for write only register
@@ -230,6 +233,7 @@ class TestWrite(RegTestBase):
                                                accesswidth=self.dut.accesswidth, data=1)
             read_patch.assert_not_called()
 
+
 class TestReadWrite(RegTestBase):
     """
     Test for read/write register
@@ -423,7 +427,6 @@ class TestReadWrite(RegTestBase):
                                                accesswidth=self.dut.accesswidth)
             write_patch.assert_not_called()
 
-
     def test_context_manager_read(self) -> None:
         """
         Check the write back has occurred, this happens by default even if nothing has changed in
@@ -508,3 +511,22 @@ class TestReadWrite(RegTestBase):
             write_patch.assert_called_once_with(addr=0,
                                                 width=self.dut.width,
                                                 accesswidth=self.dut.accesswidth, data=1)
+
+
+class TestRegWidthUtility(unittest.TestCase):
+    """
+    Test for the register width calculations
+    """
+
+    def test_legal_reg_width(self):
+        """
+        Test the register widths
+        """
+        self.assertFalse(legal_register_width(-1))
+        self.assertFalse(legal_register_width(0))
+        self.assertFalse(legal_register_width(4))
+        for width_power in range(3, 20):
+            reg_width = 1 << width_power
+            self.assertTrue(legal_register_width(reg_width))
+            self.assertFalse(legal_register_width(reg_width + 1))
+            self.assertFalse(legal_register_width(reg_width - 1))
